import os
import json
import urllib.parse
import re

def natural_sort_key(s):
    return [int(c) if c.isdigit() else c.lower() for c in re.split(r'(\d+)', s)]

def generate_book_json(base_dir):
    library = {"branches": []}
    
    for branch in sorted(os.listdir(base_dir), key=natural_sort_key):
        branch_path = os.path.join(base_dir, branch)
        if os.path.isdir(branch_path):
            branch_data = {"name": branch, "sections": []}
            
            for section in sorted(os.listdir(branch_path), key=natural_sort_key):
                section_path = os.path.join(branch_path, section)
                if os.path.isdir(section_path):
                    section_data = {"name": section, "books": []}
                    
                    for book in sorted(os.listdir(section_path), key=natural_sort_key):
                        book_path = os.path.join(section_path, book)
                        if os.path.isfile(book_path) and book.endswith(".pdf"):
                            book_title = book
                            book_url = f"https://devturki.com/SudanBooks/{urllib.parse.quote(branch)}/{urllib.parse.quote(section)}/{urllib.parse.quote(book)}"
                            book_data = {
                                "title": book_title,
                                "url": book_url
                            }
                            section_data["books"].append(book_data)
                    
                    branch_data["sections"].append(section_data)
            
            library["branches"].append(branch_data)
    
    return library

base_directory = "/var/www/html/pdfs/SudanBooks"
library_json = generate_book_json(base_directory)

with open("books.json", "w", encoding="utf-8") as json_file:
    json.dump(library_json, json_file, indent=4, ensure_ascii=False)

print("books.json generated successfully.")